﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Infragistics.Web.Mvc;
using hierarchical_grid_load_on_demand_demo.Models;

namespace hierarchical_grid_load_on_demand_demo.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult AspNetMvc()
        {
            //pass a grid model to the view
            GridModel grid = CreateGridModel();
            return View(grid);
        }


        // Take grid creation outside as it will be used in all methods:
        private GridModel CreateGridModel()
        {
            GridModel grid = new GridModel();

            // Set up properties and columns:
            grid.AutoGenerateColumns = false;
            grid.Columns = new List<GridColumn>();
            grid.Columns.Add(new GridColumn("Customer", "CustomerID", "string", "300px"));
            grid.Columns.Add(new GridColumn("Company Name", "CompanyName", "string", "150px"));
            grid.Columns.Add(new GridColumn("Country", "Country", "string", "150px"));

            grid.PrimaryKey = "CustomerID";
            grid.AutoGenerateLayouts = false;

            // Create child layout
            GridColumnLayoutModel layout = new GridColumnLayoutModel();
            layout.Key = "Orders";
            layout.ForeignKey = "CustomerID";
            layout.PrimaryKey = "OrderID";
            layout.AutoGenerateColumns = false;

            layout.Columns = new List<GridColumn>();
            layout.Columns.Add(new GridColumn("Order ID", "OrderID", "number", "100px"));
            layout.Columns.Add(new GridColumn("Customer", "CustomerID", "string", "100px"));
            layout.Columns.Add(new GridColumn("Order Date", "OrderDate", "date", "150px"));
            layout.Columns.Add(new GridColumn("Shipped Date", "ShippedDate", "date", "150px"));

            // Add paging to child layouts (different from the parent's)
            GridPaging layoutPaging = new GridPaging();
            layoutPaging.VisiblePageCount = 2;
            layoutPaging.PageSize = 5;
            layoutPaging.Type = OpType.Remote;
            layout.Features.Add(layoutPaging);
            
            //add that layout to the grid
            grid.ColumnLayouts.Add(layout);

            //most importantly turn Load On demand on and define response Urls:
            grid.LoadOnDemand = true;
            grid.DataSourceUrl = this.Url.Action("BindParent");
            grid.ColumnLayouts[0].DataSourceUrl = this.Url.Action("BindChild");

            //Add features:
            GridSorting sorting = new GridSorting();
            sorting.Type = OpType.Remote;
            grid.Features.Add(sorting);
            GridPaging paging = new GridPaging();
            paging.PageSize = 10;
            paging.Type = OpType.Remote;
            grid.Features.Add(paging);

            //And lastly set ID so the client widget can be normally interacted with (see the events in the view)
            grid.ID = "hierarchicalGrid";

            // Return the finished model
            return grid;
        }

        public JsonResult BindParent()
        {
            //create a model
            GridModel grid = CreateGridModel();
            //set its datasource
            var dataContext = new NorthwindDataContext();
            var dataSource = dataContext.Customers;
            grid.DataSource = dataSource.Take(30);
            //and use the GetData() method to return the results
            return grid.GetData();
        }

        public JsonResult BindChild(string path, string layout)
        {
            //create a model
            GridModel grid = CreateGridModel();
            //set its datasource
            var dataContext = new NorthwindDataContext();
            var dataSource = dataContext.Orders;
            grid.DataSource = dataSource;
            //and use the GetData() method to return the results
            return grid.GetData(path, layout);
        }

        public ActionResult jQuery()
        {
            return View();
        }
    }
}
